==> Statemate4.6.1.7Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Dataport/wwhdata/js/search/pairs/pair262.js <==
function FileData_Pairs(x)
{
x.t("instance","activities");
x.t("type","input");
x.t("type","stm_r_ch_define_ac");
x.t("type","query");
x.t("explicitly","defined");
x.t("stm_r_ch_defining_cd_inst_ac","stm_list");
x.t("stm_r_ch_defining_cd_inst_ac","query");
x.t("list","type");
x.t("list","explicitly");
x.t("list","syntax");
x.t("status","stm_r_ch_defining_cd_inst_ac");
x.t("status","stm_r_ch_describing_ac");
x.t("status","stm_r_ch_defining_ac");
x.t("stm_r_ch_describing_ac","stm_list");
x.t("stm_r_ch_describing_ac","query");
x.t("stm_list","in_list");
x.t("int","status");
x.t("input","list");
x.t("stm_r_ch_define_ac","stm_list");
x.t("stm_r_ch_define_ac","query");
x.t("defining","given");
x.t("functions","charts");
x.t("charts","(ch)");
x.t("charts","given");
x.t("charts","activities");
x.t("syntax","stm_r_ch_defining_cd_inst_ac");
x.t("syntax","stm_r_ch_describing_ac");
x.t("syntax","stm_r_ch_define_ac");
x.t("syntax","stm_r_ch_defining_ac");
x.t("activity-charts","defining");
x.t("activity-charts","define");
x.t("activity","purpose");
x.t("activity","defined");
x.t("stm_r_ch_defining_ac","stm_list");
x.t("stm_r_ch_defining_ac","query");
x.t("control","activity");
x.t("control","activities");
x.t("define","instance");
x.t("(ch)","input");
x.t("purpose","syntax");
x.t("purpose","returns");
x.t("describing","given");
x.t("given","activity");
x.t("given","control");
x.t("statecharts","describing");
x.t("statecharts","describe");
x.t("query","functions");
x.t("query","charts");
x.t("query","activity-charts");
x.t("query","purpose");
x.t("query","statecharts");
x.t("defined","purpose");
x.t("defined","unresolved");
x.t("activities","input");
x.t("in_list","int");
x.t("returns","charts");
x.t("returns","activity-charts");
x.t("returns","statecharts");
x.t("unresolved","syntax");
x.t("describe","control");
}

==> Statemate4.6.1.10Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Dataport/wwhdata/js/search/pairs/pair262.js <==
function FileData_Pairs(x)
{
x.t("instance","activities");
x.t("type","input");
x.t("type","stm_r_ch_define_ac");
x.t("type","query");
x.t("explicitly","defined");
x.t("stm_r_ch_defining_cd_inst_ac","stm_list");
x.t("stm_r_ch_defining_cd_inst_ac","query");
x.t("list","type");
x.t("list","explicitly");
x.t("list","syntax");
x.t("status","stm_r_ch_defining_cd_inst_ac");
x.t("status","stm_r_ch_describing_ac");
x.t("status","stm_r_ch_defining_ac");
x.t("stm_r_ch_describing_ac","stm_list");
x.t("stm_r_ch_describing_ac","query");
x.t("stm_list","in_list");
x.t("int","status");
x.t("input","list");
x.t("stm_r_ch_define_ac","stm_list");
x.t("stm_r_ch_define_ac","query");
x.t("defining","given");
x.t("functions","charts");
x.t("charts","(ch)");
x.t("charts","given");
x.t("charts","activities");
x.t("syntax","stm_r_ch_defining_cd_inst_ac");
x.t("syntax","stm_r_ch_describing_ac");
x.t("syntax","stm_r_ch_define_ac");
x.t("syntax","stm_r_ch_defining_ac");
x.t("activity-charts","defining");
x.t("activity-charts","define");
x.t("activity","purpose");
x.t("activity","defined");
x.t("stm_r_ch_defining_ac","stm_list");
x.t("stm_r_ch_defining_ac","query");
x.t("control","activity");
x.t("control","activities");
x.t("define","instance");
x.t("(ch)","input");
x.t("purpose","syntax");
x.t("purpose","returns");
x.t("describing","given");
x.t("given","activity");
x.t("given","control");
x.t("flowchars","describing");
x.t("flowchars","describe");
x.t("statecharts","flowchars");
x.t("query","functions");
x.t("query","charts");
x.t("query","activity-charts");
x.t("query","purpose");
x.t("query","statecharts");
x.t("defined","purpose");
x.t("defined","unresolved");
x.t("activities","input");
x.t("in_list","int");
x.t("returns","charts");
x.t("returns","activity-charts");
x.t("returns","statecharts");
x.t("unresolved","syntax");
x.t("describe","control");
}
